@@ -1,3 +1,6 @@
+#
+# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -13,8 +16,18 @@
 
 import gobject
 import gtk
+import os
+import sys
+from KeyMappings import *
 from ZeemoteEventThread import ZeemoteEventThread
 
+# If a user config directoryis present try to load mappings
+# from there.
+userConfigPath = os.getenv("HOME") + "/.zeecontrol"
+if os.path.isdir(userConfigPath):
+  sys.path.append(userConfigPath)
+  from UserMappings import *
+
 class ZeeButton():
   def __init__(self, gui, container, id):
     self.id = id
@@ -28,7 +41,7 @@ class ZeeButton():
     self.label = gtk.Label("")
     self.eb = gtk.EventBox()
     self.eb.add(self.label)
-    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#FF0000'))
+    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#880000'))
     self.vbox.add(self.eb)
 
     self.button = gtk.Button(str(id))
@@ -40,15 +53,16 @@ class ZeeButton():
       self.connect()
 
   def connect(self):
-    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#0000FF'))
+    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#000088'))
     self.gui.signalUser("Trying to connect Zeemote %d." % self.id)
     gobject.threads_init()
     self.eventThread = ZeemoteEventThread(self)
     self.eventThread.start()
 
   def signalConnected(self):
-    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#00FF00'))
+    self.eb.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('#008800'))
     self.gui.signalUser("Zeemote %d connected. Have fun!" % self.id)
+    self.setMapping(defaultMappings[self.id])
     self.connected = True
 
   def callback(self, widget):
@@ -58,10 +72,11 @@ class ZeeButton():
     else:
       self.gui.setSelectedZeeButton(self)
 
-  def setMapping(self, mapping, altMapping):
-    print "Setting mapping for Zeemote %d" % self.id
-    self.eventThread.setMapping(mapping)
-    self.eventThread.setAltMapping(altMapping)
+  def setMapping(self, m):
+    print "Setting mapping for Zeemote %d to %s." % (self.id, m)
+    self.eventThread.setMapping(globals()["mapping"+m])
+    self.eventThread.setAltMapping(globals()["altMapping"+m])
+    self.label.set_text(m)
 
   def getId(self):
     return self.id
